type RegionFeatureProperties = {
    id: string;
    iso1A2: string | undefined;
    iso1A3: string | undefined;
    iso1N3: string | undefined;
    m49: string | undefined;
    wikidata: string;
    emojiFlag: string | undefined;
    ccTLD: string | undefined;
    nameEn: string;
    aliases: Array<string> | undefined;
    country: string | undefined;
    groups: Array<string>;
    members: Array<string> | undefined;
    level: string;
    isoStatus: string | undefined;
    driveSide: string | undefined;
    roadSpeedUnit: string | undefined;
    roadHeightUnit: string | undefined;
    callingCodes: Array<string> | undefined;
};
type RegionFeature = {
    type: string;
    geometry: any;
    properties: RegionFeatureProperties;
};
type RegionFeatureCollection = {
    type: string;
    features: Array<RegionFeature>;
};
type Vec2 = [number, number];
type Bbox = [number, number, number, number];
type PointGeometry = {
    type: string;
    coordinates: Vec2;
};
type PointFeature = {
    type: string;
    geometry: PointGeometry;
    properties: any;
};
type Location = Vec2 | PointGeometry | PointFeature;
type CodingOptions = {
    level?: string | undefined;
    maxLevel?: string | undefined;
    withProp?: string | undefined;
};
export declare let borders: RegionFeatureCollection;
export declare function feature(query: Location | string | number, opts?: CodingOptions): RegionFeature | null;
export declare function iso1A2Code(query: Location | string | number, opts?: CodingOptions): string | null;
export declare function iso1A3Code(query: Location | string | number, opts?: CodingOptions): string | null;
export declare function iso1N3Code(query: Location | string | number, opts?: CodingOptions): string | null;
export declare function m49Code(query: Location | string | number, opts?: CodingOptions): string | null;
export declare function wikidataQID(query: Location | string | number, opts?: CodingOptions): string | null;
export declare function emojiFlag(query: Location | string | number, opts?: CodingOptions): string | null;
export declare function ccTLD(query: Location | string | number, opts?: CodingOptions): string | null;
export declare function iso1A2Codes(query: Location | Bbox): Array<string>;
export declare function iso1A3Codes(query: Location | Bbox): Array<string>;
export declare function iso1N3Codes(query: Location | Bbox): Array<string>;
export declare function m49Codes(query: Location | Bbox): Array<string>;
export declare function wikidataQIDs(query: Location | Bbox): Array<string>;
export declare function emojiFlags(query: Location | Bbox): Array<string>;
export declare function ccTLDs(query: Location | Bbox): Array<string>;
export declare function featuresContaining(query: Location | Bbox | string | number, strict?: boolean): Array<RegionFeature>;
export declare function featuresIn(id: string | number, strict?: boolean): Array<RegionFeature>;
export declare function aggregateFeature(id: string | number): RegionFeature | null;
export declare function isIn(query: Location | string | number, bounds: string | number): boolean | null;
export declare function isInEuropeanUnion(query: Location | string | number): boolean | null;
export declare function isInUnitedNations(query: Location | string | number): boolean | null;
export declare function driveSide(query: Location | string | number): string | null;
export declare function roadSpeedUnit(query: Location | string | number): string | null;
export declare function roadHeightUnit(query: Location | string | number): string | null;
export declare function callingCodes(query: Location | string | number): Array<string>;
export {};
